Welcome to xtremes' documentation!
===================================

**xtremes** is a Python library for various utilities useful in Extreme Value Statistics. So far, you will find tools to fit more than one 
order statistics for parameter estimation as well as a Bootstrap device.

It is created within the ClimXtreme project and will provide supplementary code and simulations for the papers yet to come.

Check out the :doc:`usage` section for further information, including
how to :ref:`installation` the project.

.. note::

   This project is under active and heavy development.

.. toctree::
   :maxdepth: 2
   :caption: Chapters   

   usage
   topt
   bootstrap
   biascorrection
   miscellaneous
   api_topt
   api_bootstrap
   api_misc
   api_biascorrection
